@@ -1,25 +1,10 @@
-/*
- * This file is part of Tepl, a text editor library.
+/* From gedit-utils.c:
+ * SPDX-FileCopyrightText: 1998, 1999 - Alex Roberts, Evan Lawrence
+ * SPDX-FileCopyrightText: 2000, 2002 - Chema Celorio, Paolo Maggi
+ * SPDX-FileCopyrightText: 2003-2005 - Paolo Maggi
  *
- * From gedit-utils.c:
- * Copyright 1998, 1999 - Alex Roberts, Evan Lawrence
- * Copyright 2000, 2002 - Chema Celorio, Paolo Maggi
- * Copyright 2003-2005 - Paolo Maggi
- *
- * Copyright 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
- *
- * Tepl is free software; you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the
- * Free Software Foundation; either version 2.1 of the License, or (at your
- * option) any later version.
- *
- * Tepl is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
- * License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2016-2020 - Sébastien Wilmet <swilmet@gnome.org>
+ * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #include "tepl-utils.h"
@@ -744,3 +729,69 @@ tepl_utils_show_warning_dialog (GtkWindow   *parent,
 
 	gtk_widget_show (dialog);
 }
+
+/**
+ * tepl_utils_binding_transform_func_smart_bool:
+ * @binding: a #GBinding.
+ * @from_value: the #GValue containing the value to transform.
+ * @to_value: the #GValue in which to store the transformed value.
+ * @user_data: data passed to the transform function.
+ *
+ * A #GBindingTransformFunc to transform between these two #GValue types:
+ * - A #GValue of type #gboolean.
+ * - A #GValue of type #GVariant, with the #GVariant of type boolean.
+ *
+ * For convenience, this function works in both directions (hence the “smart”),
+ * it introspects the types of @from_value and @to_value.
+ *
+ * Note that if @from_value and @to_value are of the same #GValue type, this
+ * function won't work and you shouldn't use a custom #GBindingTransformFunc in
+ * the first place.
+ *
+ * Returns: %TRUE if the transformation was successful, and %FALSE otherwise.
+ * Since: 5.0
+ */
+gboolean
+tepl_utils_binding_transform_func_smart_bool (GBinding     *binding,
+					      const GValue *from_value,
+					      GValue       *to_value,
+					      gpointer      user_data)
+{
+	g_return_val_if_fail (G_IS_VALUE (from_value), FALSE);
+	g_return_val_if_fail (G_IS_VALUE (to_value), FALSE);
+
+	if (G_VALUE_TYPE (from_value) == G_TYPE_BOOLEAN &&
+	    G_VALUE_TYPE (to_value) == G_TYPE_VARIANT)
+	{
+		gboolean bool_value;
+
+		bool_value = g_value_get_boolean (from_value);
+		g_value_set_variant (to_value, g_variant_new_boolean (bool_value));
+
+		return TRUE;
+	}
+	else if (G_VALUE_TYPE (from_value) == G_TYPE_VARIANT &&
+		 G_VALUE_TYPE (to_value) == G_TYPE_BOOLEAN)
+	{
+		GVariant *variant_value;
+		gboolean bool_value;
+
+		variant_value = g_value_get_variant (from_value);
+		if (variant_value == NULL)
+		{
+			return FALSE;
+		}
+
+		if (!g_variant_type_equal (g_variant_get_type (variant_value), G_VARIANT_TYPE_BOOLEAN))
+		{
+			return FALSE;
+		}
+
+		bool_value = g_variant_get_boolean (variant_value);
+		g_value_set_boolean (to_value, bool_value);
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
